#!/bin/sh

#
#  Installer.command
#  SalesboxCRM - Installer is for OS X 10.9 & above.
#
#  Created by Jeevanandam M. on Apr 02, 2016.
#
#  Revision
#  1.0	Created an initial installer script
#

sb_user=${USER}
sb_install_path=${HOME}/Library/Mail/Bundles
sb_plugin=${sb_install_path}/SalesboxCRM.mailbundle
sb_plugin_plist=${sb_plugin}/Contents/Info.plist

CC='\033[00m'
RCB='\033[01;31m'
GCB='\033[01;32m'
RC='\033[31m'
GC='\033[32m'
WC='\033[37m'
RCWHB='\033[1;31;43;5m'
BOLD='\033[1m'

echo "\n\nSalesboxCRM - Starting installation...\n"
echo "Mail Plugin - ${BOLD}SalesboxCRM${CC}"

sb_mac_osx_version_p=`sw_vers -productVersion | cut -d . -f 1,2,3`
sb_mac_osx_version=`sw_vers -productVersion | cut -d . -f 1,2`
echo "Mac OS X version: ${sb_mac_osx_version_p}"

sb_mail_version=$(defaults read /Applications/Mail.app/Contents/Info CFBundleShortVersionString)
sb_mail_build_version=$(defaults read /Applications/Mail.app/Contents/Info CFBundleVersion)
echo "Mail.app ${sb_mail_version} [Build ${sb_mail_build_version}]"

if [ ! -e "${sb_install_path}" ]; then
	echo "'${sb_install_path}' directory not exists, creating one"
    mkdir -p "${sb_install_path}"
fi

sb_enable_plugin=1
if [ -s "${sb_plugin}" ]; then
	echo "\nPlugin is already installed, let's upgrade it"
	rm -rf "${sb_plugin}"
else
	echo "\nInstalling SalesboxCRM Mail plugin"
fi

sb_current_dir=`dirname "$0"`
cp -r "${sb_current_dir}/SalesboxCRM.mailbundle" "${sb_install_path}"

sb_enb_success=0
if [ ${sb_user} == root ] ; then
    echo "Root users is installing plugin"
    domain=/Library/Preferences/com.apple.mail.plist
else
    echo "user '${sb_user}' is installing plugin"
   domain="/Users/${sb_user}/Library/Containers/com.apple.mail/Data/Library/Preferences/com.apple.mail.plist"
fi

if [ ${sb_enable_plugin} -eq 1 ]; then
if [ -f ${domain} ]; then
    echo "Enabling plugin support in Mail.app"
    defaults write "${domain}" EnableBundles -bool true
    sb_enb_success=1
fi

if [ ${sb_enb_success} -eq 0 ]; then
	domain="/Users/${sb_user}/Library/Preferences/com.apple.mail.plist"
	defaults write "${domain}" EnableBundles -bool true
fi
echo "Domain is ${domain}"
fi

if [ -f /Applications/Mail.app/Contents/Info.plist ]; then
sb_mail_app_uuid=$(defaults read /Applications/Mail.app/Contents/Info.plist PluginCompatibilityUUID)
    if [[ ! -z "${sb_mail_app_uuid}" ]]; then
        echo "Adding UUID ${sb_mail_app_uuid}"
        defaults write "${sb_plugin_plist}" SupportedPluginCompatibilityUUIDs -array-add "${sb_mail_app_uuid}"
    fi
fi

if [ ${sb_user} == root ] ; then
	sb_cur_user_name=${HOME##*/}
	echo "Applying appropriate file permission for user '${sb_cur_user_name}'"
	chown -R "${sb_cur_user_name}" "${sb_install_path}"
	chmod -R 755 "${sb_install_path}"
fi

# Writing Salesbox Website URL and Support URL
defaults write "${sb_plugin_plist}" SBSalesboxWebsiteUrl "http://salesbox.com"
defaults write "${sb_plugin_plist}" SBSalesboxSupportUrl "http://salesbox.com"

echo "Installation completed." 

echo "\n================================================================================="
echo "  ${GCB}SalesboxCRM Mail Plugin successfully installed${CC}, ${RCWHB} please restart the Mail.app ${CC}  "
echo "=================================================================================\n\n"
